@@ -9,6 +9,8 @@ $lang['add'] = 'Add';
 
 #C
 $lang['cancel'] = 'Cancel';
+$lang['clear_coupons'] = 'Clear Coupons';
+$lang['coupons_cleared'] = 'We have reset all of your coupons';
 $lang['couponformtemplate_addedit'] = 'Add or Edit a Coupon Form Template';
 
 
@@ -22,6 +24,7 @@ EOT;
 #E
 $lang['edit'] = 'Edit';
 $lang['error_already_prod'] = 'A product condition already exists in the condition list';
+$lang['error_coupon_exists'] = 'A promotion using that coupon string already exists';
 $lang['error_duplicate_condition'] = 'A duplicate condition already exists in the condition list';
 $lang['error_duplicate_type'] = 'A duplicate product condition already exists';
 $lang['error_empty_code'] = 'Please enter a valid value';
@@ -286,4 +289,4 @@ $lang['warning_no_conditions'] = 'You have not specified any conditions for this
 #Z
 
 
-?>
\ No newline at end of file
+?>
